@@ -41,7 +41,7 @@ private:
 	KConfig *kconf;
 	bool *p_ac;
 	int *p_dpi;
-	QCheckBox *ac_b;
+	QCheckBox *ac_b,*br_b,*cn_b;
 	QLineEdit *dpi_e;
 };
 
